@@ -1,5 +1,9 @@
 context('rgf R-package tests')
 
+# ............................................................................................................ I have to disable the tests on CRAN due to the fact that I don't know beforehand which Python version it uses and I receive errors
+# # don't run tests on CRAN [ see: https://github.com/rstudio/reticulate/issues/715#issuecomment-700821462 ]
+#............................................................................................................
+
 
 # Tests for 'RGF_Regressor' & 'RGF_Classifier'
 
@@ -8,11 +12,7 @@ context('rgf R-package tests')
 
 testthat::test_that("the methods of the 'RGF_Regressor' class return the correct output", {
 
-  #............................................................................................................ keep this as a reference as I might have to disable the tests on CRAN due to the fact that I don't know beforehand which Python version it uses
-  # # don't run tests on CRAN [ see: https://github.com/rstudio/reticulate/issues/715#issuecomment-700821462 ]
-  # testthat::skip_on_cran()
-  #............................................................................................................
-
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
@@ -42,6 +42,7 @@ testthat::test_that("the methods of the 'RGF_Regressor' class return the correct
 
 testthat::test_that("the methods of the 'RGF_Classifier' class return the correct output (binary classification)", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
@@ -70,6 +71,7 @@ testthat::test_that("the methods of the 'RGF_Classifier' class return the correc
 
 testthat::test_that("the methods of the 'RGF_Classifier' class return the correct output (multiclass classification)", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
@@ -103,6 +105,7 @@ testthat::test_that("the methods of the 'RGF_Classifier' class return the correc
 
 testthat::test_that("the methods of the 'FastRGF_Regressor' class return the correct output", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
@@ -137,6 +140,7 @@ testthat::test_that("the methods of the 'FastRGF_Regressor' class return the cor
 
 testthat::test_that("the methods of the 'FastRGF_Classifier' class return the correct output (binary classification)", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
@@ -166,6 +170,7 @@ testthat::test_that("the methods of the 'FastRGF_Classifier' class return the co
 
 testthat::test_that("the methods of the 'FastRGF_Classifier' class return the correct output (multiclass classification)", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
@@ -201,6 +206,7 @@ testthat::test_that("the methods of the 'FastRGF_Classifier' class return the co
 
 testthat::test_that("the 'mat_2scipy_sparse' returns an error in case that the data is not inheriting matrix class", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("scipy")
 
@@ -212,6 +218,7 @@ testthat::test_that("the 'mat_2scipy_sparse' returns an error in case that the d
 
 testthat::test_that("the 'mat_2scipy_sparse' returns an error in case that the 'format' parameter is invalid", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("scipy")
 
@@ -221,6 +228,7 @@ testthat::test_that("the 'mat_2scipy_sparse' returns an error in case that the '
 
 testthat::test_that("the 'mat_2scipy_sparse' returns a scipy CSR sparse matrix", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("scipy")
 
@@ -234,6 +242,7 @@ testthat::test_that("the 'mat_2scipy_sparse' returns a scipy CSR sparse matrix",
 
 testthat::test_that("the 'mat_2scipy_sparse' returns a scipy CSC sparse matrix", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("scipy")
 
@@ -258,6 +267,7 @@ if (Sys.info()["sysname"] != 'Darwin') {
 
   testthat::test_that("the 'TO_scipy_sparse' returns an error in case that the input object is not of type 'dgCMatrix' or 'dgRMatrix'", {
 
+    testthat::skip_on_cran()
     skip_test_if_no_python()
     skip_test_if_no_module("scipy")
 
@@ -269,6 +279,7 @@ if (Sys.info()["sysname"] != 'Darwin') {
 
   testthat::test_that("the 'TO_scipy_sparse' returns the correct output for dgCMatrix", {
 
+    testthat::skip_on_cran()
     skip_test_if_no_python()
     skip_test_if_no_module("scipy")
 
@@ -290,6 +301,7 @@ if (Sys.info()["sysname"] != 'Darwin') {
 
   testthat::test_that("the 'TO_scipy_sparse' returns the correct output for dgRMatrix", {
 
+    testthat::skip_on_cran()
     skip_test_if_no_python()
     skip_test_if_no_module("scipy")
 
@@ -314,6 +326,7 @@ if (Sys.info()["sysname"] != 'Darwin') {
 
   testthat::test_that("the RGF_Regressor works with sparse (scipy) matrices", {
 
+    testthat::skip_on_cran()
     skip_test_if_no_python()
     skip_test_if_no_module(c("rgf.sklearn", 'scipy'))
 
@@ -355,6 +368,7 @@ if (Sys.info()["sysname"] != 'Darwin') {
 
 testthat::test_that("the feature importances of the 'RGF_Regressor' class works as expected", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
@@ -374,6 +388,7 @@ testthat::test_that("the feature importances of the 'RGF_Regressor' class works
 
 testthat::test_that("the 'dump_model' method returns the correct output (Dumps the forest information to the R session -- works ONLY for RGF and NOT for FastRGF)", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
@@ -425,6 +440,7 @@ testthat::test_that("the 'dump_model' method returns the correct output (Dumps t
 
 testthat::test_that("the 'save_model' method returns the correct output -- works ONLY for RGF and NOT for FastRGF", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
@@ -463,6 +479,7 @@ testthat::test_that("the 'save_model' method returns the correct output -- works
 
 testthat::test_that("the 'cleanup' method (ESTIMATOR specific) works as expected for both RGF and FastRGF (checking of the size of the temporary directory before and after the '$fit' method)", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
@@ -507,6 +524,7 @@ testthat::test_that("the 'cleanup' method (ESTIMATOR specific) works as expected
 
 testthat::test_that("the 'cleanup' method (APPLIES TO ALL ESTIMATORS) works as expected for both RGF and FastRGF (checking of the size of the temporary directory before and after the '$fit' method)", {
 
+  testthat::skip_on_cran()
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
